/*
 * Copyright 2024 Foster Hangdaan
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import Site, { SiteOptions } from "lume/core/site.ts";
import lume, { PluginOptions } from "lume/mod.ts";
import { DeepPartial } from "lume/core/utils/object.ts";
import { Writer } from "lume/core/writer.ts";
import { fromFileUrl, join } from "@std/path";

const specifier = "./";
const cwdUrl = await import.meta.resolve?.(specifier);
if (!cwdUrl) {
  throw new Error(
    `Attempted to resolve ${specifier} but got ${cwdUrl} instead.`,
  );
}
const cwd = fromFileUrl(cwdUrl);

class TestWriter implements Writer {
  savePages() {
    return Promise.resolve([]);
  }

  copyFiles() {
    return Promise.resolve([]);
  }

  clear(): Promise<void> {
    return Promise.resolve();
  }

  removeFiles(): Promise<void> {
    return Promise.resolve();
  }
}

export function getSite(
  siteOptions: DeepPartial<SiteOptions> = {},
  pluginOptions: PluginOptions = {},
): Site {
  siteOptions.cwd = join(cwd, "site");

  const site = lume(
    siteOptions,
    pluginOptions,
    false,
  );

  site.writer = new TestWriter();

  return site;
}
